.. Antidote documentation master file, created by
   sphinx-quickstart on Sat Oct 14 22:07:20 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. highlight:: python


.. include:: _build/README.rst


Table of Content
================

.. toctree::
    :maxdepth: 2

    tutorial
    faq
    recipes
    how_to
    extend
    reference
    changelog

